#[repr(C)]pub enum QueryLanguage {
AQL = 0,
AQLQuirksV3 = 1,
}Expand description
An enum over all supported query languages of graphANNIS.
Currently, only the ANNIS Query Language (AQL) and its variants are supported, but this enum allows us to add a support for older query language versions or completely new query languages.
Variants